@@ -8,4 +8,4 @@ class Gateway(NamespacedResource):
     Gateway object.
     """
 
-    api_version = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
+    api_group = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
